@@ -3,13 +3,13 @@ package Sah::Schema::dirname;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-19'; # DATE
+our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem directory name',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This schema is basically string with some checks and prefilters. Why use this
 schema instead of plain ol' str? Mainly to give you the ability to change tilde
@@ -25,7 +25,7 @@ like `foo//bar` into `foo/bar`.
 What's the difference between this schema and `filename`? The default completion
 rule. This schema's completion by default only includes directories.
 
-_
+MARKDOWN
 
     min_len => 1,
 
@@ -58,7 +58,7 @@ Sah::Schema::dirname - Filesystem directory name
 
 =head1 VERSION
 
-This document describes version 0.020 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.021 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 SYNOPSIS
 
@@ -86,7 +86,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -101,8 +101,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo/bar";
- my $res = $validator->($data); # => ["","foo/bar"]
+ $data = "foo";
+ my $res = $validator->($data); # => ["","foo"]
  
  # a sample invalid data
  $data = "";
