@@ -3,9 +3,9 @@ package Sah::Schema::dirname::unix;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-19'; # DATE
+our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem directory name on a Unix system',
@@ -49,7 +49,7 @@ Sah::Schema::dirname::unix - Filesystem directory name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.020 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.021 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo//bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -98,7 +98,7 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo//bar";
  my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
