@@ -3,13 +3,13 @@ package Sah::Schema::pathname;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-19'; # DATE
+our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem path name',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This schema is basically string with some checks and prefilters. Why use this
 schema instead of plain ol' str? Mainly to give you the ability to change tilde
@@ -26,7 +26,7 @@ What's the difference between this schema and `filename` and `dirname`? The
 default completion rule. This schema's completion by default includes
 files as well as directories, while `dirname`'s only include directories.
 
-_
+MARKDOWN
     min_len => 1,
 
     'x.completion' => ['filename'],
@@ -58,7 +58,7 @@ Sah::Schema::pathname - Filesystem path name
 
 =head1 VERSION
 
-This document describes version 0.020 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.021 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 SYNOPSIS
 
