@@ -3,17 +3,17 @@ package Sah::Schema::pathnames;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-19'; # DATE
+our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 our $schema = [array => {
     summary => 'List of filesystem path names',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 Coerces from string by expanding the glob pattern in the string.
 
-_
+MARKDOWN
     of => ['pathname', {req=>1}],
     'x.element_completion' => ['filename'],
     'x.perl.coerce_rules' => [
@@ -36,7 +36,7 @@ Sah::Schema::pathnames - List of filesystem path names
 
 =head1 VERSION
 
-This document describes version 0.020 of Sah::Schema::pathnames (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.021 of Sah::Schema::pathnames (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 SYNOPSIS
 
