@@ -3,9 +3,9 @@ package Sah::Schemas::Path;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-19'; # DATE
+our $DATE = '2023-10-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,7 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.020 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.021 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,7 @@ C<filename>, C<dirname>, C<pathname> are basically the same; they differ in the
 completion they provide, i.e. C<dirname> offers completion of only directory
 names.
 
-Use C<filename::unix>, F<dirname::unix>, F<pathname::unix> only if you want to
+Use C<filename::unix>, C<dirname::unix>, C<pathname::unix> only if you want to
 accept Unix-style path. These schemas contain additional checks that are
 specific to Unix filesystem.
 
@@ -74,6 +74,17 @@ What's the difference between this schema and C<filename>? The default completio
 rule. This schema's completion by default only includes directories.
 
 
+=item * L<dirname::default_curdir|Sah::Schema::dirname::default_curdir>
+
+Directory name, default to current directory.
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. a
+C<delete-files-in> script). It is safer to use this schema to perform a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by
+default.
+
+
 =item * L<dirname::exists|Sah::Schema::dirname::exists>
 
 Directory name, must exist on filesystem.
